now does rescaling on 256base instead of 100; removes a lot of division by a shift right 8

Needs testing!!! Volunteer please come in. 
Benefits of change:
-248 bytes code generated used gcc 4.7.2
-huge performance increase. My measurements:
   simple mix goes down from 2,87msec to 1.93msec
   middle complex mix goes down from 3,37msec to 2,00msec
   complex mix (with phase change) goes down from 6,87msec to 4,18msec
This commit is contained in:
open.20.fsguruh@xoxy.net
2013-02-18 20:26:16 +00:00
parent 71b311cb26
commit 63e2ae60a5
3 changed files with 168 additions and 49 deletions
+2
View File
@@ -37,6 +37,8 @@
#define NO_HI_LEN 25
// RESX range is used for internal calculation; The menu says -100.0 to 100.0; internally it is -1024 to 1024 to allow some optimizations
#define RESX_SHIFT 10
#define RESX 1024
#define RESXu 1024u
#define RESXul 1024ul